@@ -78,7 +78,6 @@ int get_value (char *key, char *value)
 	fclose (conffile);
 	return -1;
     }
-
 }
 
 void init_conf (void)
@@ -89,6 +88,7 @@ void init_conf (void)
     strcpy ((char *) config_options.exclude_paths, "");
     strcpy ((char *) config_options.email, "root");
     strcpy ((char *) config_options.forbidden_paths, "");
+    strcpy ((char *) config_options.ignore_dirs, "");
     config_options.keep_logs = 3;
 
     if (config_options.flags & FLAG_SPOT) {
@@ -102,6 +102,7 @@ void init_conf (void)
 
     check_return (get_value ("EMAIL", config_options.email), "EMAIL", 0);
     check_return (get_value ("EXCLUDE", config_options.exclude_paths), "EXCLUDE", 0);
+    check_return (get_value ("IGNORE_DIRS", config_options.ignore_dirs), "IGNORE_DIRS", 0);
     check_return (get_value ("LOG_FILE", config_options.log_file), "LOG_FILE", 1);
     check_return (get_value ("FORBIDDEN", config_options.forbidden_paths), "FORBIDDEN", 0);
 
